==> gatsby-matrix-theme-38.0.29.tgz: package/src/components/atoms/cards/game-cards/template-five/index.js <==
/* eslint-disable import/no-extraneous-dependencies */
import React, { useContext } from 'react';
import PropTypes from 'prop-types';
import loadable from '@loadable/component';
import { Context } from 'gatsby-core-theme/src/context/MainProvider';
import {
  imagePrettyUrl,
  getSectionExtraField,
  translate,
  getAltText,
} from 'gatsby-core-theme/src/helpers/getters';
import Button from 'gatsby-core-theme/src/components/atoms/button/button';
import OperatorCta from 'gatsby-core-theme/src/components/atoms/button/operator-cta';
import GatsbyImg from 'gatsby-core-theme/src/hooks/gatsby-img';
import Link from 'gatsby-core-theme/src/hooks/link';
import LazyImage from 'gatsby-core-theme/src/hooks/lazy-image';
import styles from './template-five.module.scss';

const TemplateFive = ({
  item,
  page,
  button_text = 'play_now_slots',
  width = 300,
  height = 250,
  useOneStarRating = true,
  affilateLink = false,
  useThumbnail = true,
  storybookImage,
  storybookLogo,
}) => {
  const { relation, path, banner } = item;
  const { name } = relation || {};
  const { translations } = useContext(Context) || {};
  const featured = !!getSectionExtraField(null, item, 'card_background_image');
  const operator = item.extra_fields?.operator;
  const provider = relation?.game_provider;
  const gameImage = (useThumbnail && relation?.thumbnail_filename_object?.filename) || banner;
  const operatorLogo = operator?.logo_url_object || operator?.logo_filename_object;
  const operatorText = operator?.one_liners?.main?.one_liner
    ? `Play at ${operator?.name} and get ${operator?.one_liners?.main?.one_liner
        .split('+')[0]
        .trim()}`
    : operator?.name || '';
  const StarRating = useOneStarRating
    ? loadable(() => import('gatsby-core-theme/src/components/molecules/star-rating/one-star'))
    : loadable(() => import('gatsby-core-theme/src/components/molecules/star-rating'));

  return (
    <div className={`${styles?.baseCard || ''} ${featured ? styles?.featured || '' : ''}`}>
      <Link
        to={path}
        className={`game-card-gtm ${styles?.cardBanner || ''}`}
        aria-label={`${name || item?.title} Link`}
      >
        {storybookImage || gameImage ? (
          <LazyImage
            width={width}
            height={height}
            src={storybookImage || imagePrettyUrl(gameImage, width, height)}
            alt={getAltText(relation?.thumbnail_filename_object, name || item?.title)}
          />
        ) : (
          <GatsbyImg filename="default-slot.jpg" alt={name || item?.title} />
        )}
      </Link>
      <div className={`${styles?.cardContent || ''} ${featured ? styles.featured || '' : ''}`}>
        <div className={styles?.cardRating || ''}>
          {relation && (
            <StarRating
              numOfStars={5}
              halfStars={false}
              rating={
                relation.rating || [
                  relation.first_rating,
                  relation.second_rating,
                  relation.third_rating,
                  relation.fourth_rating,
                ]
              }
            />
          )}
        </div>
        <Link to={path} className="game-card-gtm">
          <span className={styles?.cardTitle || ''}>{name || item?.title}</span>
        </Link>
        <div className={styles?.cardInner || ''}>
          {(storybookLogo || operatorLogo) && (
            <LazyImage
              className={styles?.cardProviderLogo || ''}
              width={48}
              height={48}
              src={storybookLogo || imagePrettyUrl(operatorLogo.filename, width, height)}
              alt={getAltText(operatorLogo, name || item?.title)}
            />
          )}
          {operator && operator.path ? (
            <Link to={operator.path} className={styles?.cardProvider || ''}>
              {operatorText}
            </Link>
          ) : (
            <Link to={provider?.path} className={styles?.cardProvider || ''}>
              <div className={styles?.cardProvider || ''}>{provider?.name}</div>
            </Link>
          )}
          {affilateLink ? (
            <>
              {operator && operator.status !== 'not_recommended' ? (
                <OperatorCta
                  module="cards_v2"
                  tracker="main"
                  operator={operator}
                  translationsObj={{
                    active: { translationKey: 'play_now_game', defaultValue: 'Play for Real' },
                    not_recommended: {
                      translationKey: 'not_recommended',
                      defaultValue: 'Not Recommended',
                    },
                    coming_soon: { translationKey: 'coming_soon', defaultValue: 'Soon Available' },
                    inactive: {
                      translationKey: 'inactive',
                      defaultValue: 'Not Accepting New Players',
                    },
                    blacklisted: { translationKey: 'blacklisted', defaultValue: 'Blacklisted' },
                  }}
                  gtmClass="operator-card-gtm btn-cta"
                  pageTemplate={page?.template}
                />
              ) : null}
            </>
          ) : (
            <Button
              to={path}
              buttonType={!featured ? 'primary' : 'secondary'}
              gtmClass="game-card-gtm btn-cta"
              btnText={translate(translations, button_text, 'Play now')}
            />
          )}
        </div>
      </div>
    </div>
  );
};

TemplateFive.propTypes = {
  item: PropTypes.shape({
    relation: PropTypes.shape({
      rating: PropTypes.string,
      first_rating: PropTypes.string,
      second_rating: PropTypes.string,
      third_rating: PropTypes.string,
      name: PropTypes.string,
      fourth_rating: PropTypes.string,
      game_provider: PropTypes.shape({
        name: PropTypes.string,
        path: PropTypes.string,
        logo_filename_object: PropTypes.shape({ filename: PropTypes.string }),
      }),
      thumbnail_filename_object: PropTypes.shape({
        filename: PropTypes.string,
        alt: PropTypes.string,
      }),
    }),
    path: PropTypes.string,
    banner: PropTypes.string,
    title: PropTypes.string,
    extra_fields: PropTypes.shape({
      operator: PropTypes.shape({
        status: PropTypes.string,
        name: PropTypes.string,
        path: PropTypes.string,
        logo_filename_object: PropTypes.shape({ filename: PropTypes.string }),
      }),
    }),
  }).isRequired,
  page: PropTypes.shape({
    template: PropTypes.string,
  }),
  button_text: PropTypes.string,
  width: PropTypes.number,
  height: PropTypes.number,
  useOneStarRating: PropTypes.bool,
  useThumbnail: PropTypes.bool,
  affilateLink: PropTypes.bool,
  storybookImage: PropTypes.string,
  storybookLogo: PropTypes.string,
};

export default TemplateFive;

==> gatsby-matrix-theme-40.0.20.tgz: package/src/components/atoms/cards/game-cards/template-five/index.js <==
/* eslint-disable import/no-extraneous-dependencies */
import React, { useContext } from 'react';
import PropTypes from 'prop-types';
import { Context } from 'gatsby-core-theme/src/context/MainProvider';
import {
  imagePrettyUrl,
  getSectionExtraField,
  translate,
  getAltText,
} from 'gatsby-core-theme/src/helpers/getters';
import Button from 'gatsby-core-theme/src/components/atoms/button/button';
import OperatorCta from 'gatsby-core-theme/src/components/atoms/button/operator-cta';
import GatsbyImg from 'gatsby-core-theme/src/hooks/gatsby-img';
import StarRating from 'gatsby-core-theme/src/components/molecules/star-rating';
import OneStarRating from 'gatsby-core-theme/src/components/molecules/star-rating/one-star';
import Link from 'gatsby-core-theme/src/hooks/link';
import LazyImage from 'gatsby-core-theme/src/hooks/lazy-image';
import styles from './template-five.module.scss';

const TemplateFive = ({
  item,
  page,
  button_text = 'play_now_slots',
  width = 300,
  height = 250,
  useOneStarRating = true,
  affilateLink = false,
  useThumbnail = true,
  storybookImage,
  storybookLogo,
}) => {
  const { relation, path, banner } = item;
  const { name } = relation || {};
  const { translations } = useContext(Context) || {};
  const featured = !!getSectionExtraField(null, item, 'card_background_image');
  const operator = item.extra_fields?.operator;
  const provider = relation?.game_provider;
  const gameImage = (useThumbnail && relation?.thumbnail_filename_object?.filename) || banner;
  const operatorLogo = operator?.logo_url_object || operator?.logo_filename_object;
  const operatorText = operator?.one_liners?.main?.one_liner
    ? `Play at ${operator?.name} and get ${operator?.one_liners?.main?.one_liner
        .split('+')[0]
        .trim()}`
    : operator?.name || '';
  const StarRatingComponent = useOneStarRating ? OneStarRating : StarRating;

  return (
    <div className={`${styles?.baseCard || ''} ${featured ? styles?.featured || '' : ''}`}>
      <Link
        to={path}
        className={`game-card-gtm ${styles?.cardBanner || ''}`}
        aria-label={`${name || item?.title} Link`}
      >
        {storybookImage || gameImage ? (
          <LazyImage
            width={width}
            height={height}
            src={storybookImage || imagePrettyUrl(gameImage, width, height)}
            alt={getAltText(relation?.thumbnail_filename_object, name || item?.title)}
          />
        ) : (
          <GatsbyImg filename="default-slot.jpg" alt={name || item?.title} />
        )}
      </Link>
      <div className={`${styles?.cardContent || ''} ${featured ? styles.featured || '' : ''}`}>
        <div className={styles?.cardRating || ''}>
          {relation && (
            <StarRatingComponent
              numOfStars={5}
              halfStars={false}
              rating={
                relation.rating || [
                  relation.first_rating,
                  relation.second_rating,
                  relation.third_rating,
                  relation.fourth_rating,
                ]
              }
            />
          )}
        </div>
        <Link to={path} className="game-card-gtm">
          <span className={styles?.cardTitle || ''}>{name || item?.title}</span>
        </Link>
        <div className={styles?.cardInner || ''}>
          {(storybookLogo || operatorLogo) && (
            <LazyImage
              className={styles?.cardProviderLogo || ''}
              width={48}
              height={48}
              src={storybookLogo || imagePrettyUrl(operatorLogo.filename, width, height)}
              alt={getAltText(operatorLogo, name || item?.title)}
            />
          )}
          {operator && operator.path ? (
            <Link to={operator.path} className={styles?.cardProvider || ''}>
              {operatorText}
            </Link>
          ) : (
            <Link to={provider?.path} className={styles?.cardProvider || ''}>
              <div className={styles?.cardProvider || ''}>{provider?.name}</div>
            </Link>
          )}
          {affilateLink ? (
            <>
              {operator && operator.status !== 'not_recommended' ? (
                <OperatorCta
                  module="cards_v2"
                  tracker="main"
                  operator={operator}
                  translationsObj={{
                    active: { translationKey: 'play_now_game', defaultValue: 'Play for Real' },
                    not_recommended: {
                      translationKey: 'not_recommended',
                      defaultValue: 'Not Recommended',
                    },
                    coming_soon: { translationKey: 'coming_soon', defaultValue: 'Soon Available' },
                    inactive: {
                      translationKey: 'inactive',
                      defaultValue: 'Not Accepting New Players',
                    },
                    blacklisted: { translationKey: 'blacklisted', defaultValue: 'Blacklisted' },
                  }}
                  gtmClass="operator-card-gtm btn-cta"
                  pageTemplate={page?.template}
                />
              ) : null}
            </>
          ) : (
            <Button
              to={path}
              buttonType={!featured ? 'primary' : 'secondary'}
              gtmClass="game-card-gtm btn-cta"
              btnText={translate(translations, button_text, 'Play now')}
            />
          )}
        </div>
      </div>
    </div>
  );
};

TemplateFive.propTypes = {
  item: PropTypes.shape({
    relation: PropTypes.shape({
      rating: PropTypes.string,
      first_rating: PropTypes.string,
      second_rating: PropTypes.string,
      third_rating: PropTypes.string,
      name: PropTypes.string,
      fourth_rating: PropTypes.string,
      game_provider: PropTypes.shape({
        name: PropTypes.string,
        path: PropTypes.string,
        logo_filename_object: PropTypes.shape({ filename: PropTypes.string }),
      }),
      thumbnail_filename_object: PropTypes.shape({
        filename: PropTypes.string,
        alt: PropTypes.string,
      }),
    }),
    path: PropTypes.string,
    banner: PropTypes.string,
    title: PropTypes.string,
    extra_fields: PropTypes.shape({
      operator: PropTypes.shape({
        status: PropTypes.string,
        name: PropTypes.string,
        path: PropTypes.string,
        logo_filename_object: PropTypes.shape({ filename: PropTypes.string }),
      }),
    }),
  }).isRequired,
  page: PropTypes.shape({
    template: PropTypes.string,
  }),
  button_text: PropTypes.string,
  width: PropTypes.number,
  height: PropTypes.number,
  useOneStarRating: PropTypes.bool,
  useThumbnail: PropTypes.bool,
  affilateLink: PropTypes.bool,
  storybookImage: PropTypes.string,
  storybookLogo: PropTypes.string,
};

export default TemplateFive;
